from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, Directory, String

Storescp_V0_1_0 = CommandToolBuilder(tool="storescp", base_command=["storescp"], inputs=[ToolInput(tag="in_arguments", input_type=Boolean(optional=True), prefix="--arguments", doc=InputDocumentation(doc="print expanded command line arguments")), ToolInput(tag="in_quiet", input_type=Boolean(optional=True), prefix="--quiet", doc=InputDocumentation(doc="quiet mode, print no warnings and errors")), ToolInput(tag="in_verbose", input_type=Boolean(optional=True), prefix="--verbose", doc=InputDocumentation(doc="verbose mode, print processing details")), ToolInput(tag="in_debug", input_type=Boolean(optional=True), prefix="--debug", doc=InputDocumentation(doc="debug mode, print debug information")), ToolInput(tag="in_log_level", input_type=Boolean(optional=True), prefix="--log-level", doc=InputDocumentation(doc="[l]evel: string constant\n(fatal, error, warn, info, debug, trace)\nuse level l for the logger")), ToolInput(tag="in_log_config", input_type=Boolean(optional=True), prefix="--log-config", doc=InputDocumentation(doc="[f]ilename: string\nuse config file f for the logger")), ToolInput(tag="in_single_process", input_type=Boolean(optional=True), prefix="--single-process", doc=InputDocumentation(doc="single process mode (default)")), ToolInput(tag="in_fork", input_type=Boolean(optional=True), prefix="--fork", doc=InputDocumentation(doc="fork child process for each association")), ToolInput(tag="in_config_file", input_type=Boolean(optional=True), prefix="--config-file", doc=InputDocumentation(doc="[f]ilename, [p]rofile: string\nuse profile p from config file f")), ToolInput(tag="in_inetd", input_type=Boolean(optional=True), prefix="--inetd", doc=InputDocumentation(doc="run from inetd super server (not with --fork)")), ToolInput(tag="in_socket_timeout", input_type=Boolean(optional=True), prefix="--socket-timeout", doc=InputDocumentation(doc="[s]econds: integer (default: 60)\ntimeout for network socket (0 for none)")), ToolInput(tag="in_acse_timeout", input_type=Boolean(optional=True), prefix="--acse-timeout", doc=InputDocumentation(doc="[s]econds: integer (default: 30)\ntimeout for ACSE messages")), ToolInput(tag="in_dim_se_timeout", input_type=Boolean(optional=True), prefix="--dimse-timeout", doc=InputDocumentation(doc="[s]econds: integer (default: unlimited)\ntimeout for DIMSE messages")), ToolInput(tag="in_ae_title", input_type=Boolean(optional=True), prefix="--aetitle", doc=InputDocumentation(doc="[a]etitle: string\nset my AE title (default: STORESCP)")), ToolInput(tag="in_max_pdu", input_type=Boolean(optional=True), prefix="--max-pdu", doc=InputDocumentation(doc="[n]umber of bytes: integer (4096..131072)\nset max receive pdu to n bytes (default: 16384)")), ToolInput(tag="in_disable_host_lookup", input_type=Boolean(optional=True), prefix="--disable-host-lookup", doc=InputDocumentation(doc="disable hostname lookup")), ToolInput(tag="in_refuse", input_type=Boolean(optional=True), prefix="--refuse", doc=InputDocumentation(doc="refuse association")), ToolInput(tag="in_reject", input_type=Boolean(optional=True), prefix="--reject", doc=InputDocumentation(doc="reject association if no implement. class UID")), ToolInput(tag="in_ignore", input_type=Boolean(optional=True), prefix="--ignore", doc=InputDocumentation(doc="ignore store data, receive but do not store")), ToolInput(tag="in_sleep_after", input_type=Boolean(optional=True), prefix="--sleep-after", doc=InputDocumentation(doc="[s]econds: integer\nsleep s seconds after store (default: 0)")), ToolInput(tag="in_sleep_during", input_type=Boolean(optional=True), prefix="--sleep-during", doc=InputDocumentation(doc="[s]econds: integer\nsleep s seconds during store (default: 0)")), ToolInput(tag="in_abort_after", input_type=Boolean(optional=True), prefix="--abort-after", doc=InputDocumentation(doc="abort association after receipt of C-STORE-RQ\n(but before sending response)")), ToolInput(tag="in_abort_during", input_type=Boolean(optional=True), prefix="--abort-during", doc=InputDocumentation(doc="abort association during receipt of C-STORE-RQ")), ToolInput(tag="in_promiscuous", input_type=Boolean(optional=True), prefix="--promiscuous", doc=InputDocumentation(doc="promiscuous mode, accept unknown SOP classes\n(not with --config-file)")), ToolInput(tag="in_uid_padding", input_type=Boolean(optional=True), prefix="--uid-padding", doc=InputDocumentation(doc="silently correct space-padded UIDs")), ToolInput(tag="in_disable_tls", input_type=Boolean(optional=True), prefix="--disable-tls", doc=InputDocumentation(doc="use normal TCP/IP connection (default)")), ToolInput(tag="in_null_passwd", input_type=Boolean(optional=True), prefix="--null-passwd", doc=InputDocumentation(doc="use empty string as password")), ToolInput(tag="in_pem_keys", input_type=Boolean(optional=True), prefix="--pem-keys", doc=InputDocumentation(doc="read keys and certificates as PEM file (default)")), ToolInput(tag="in_der_keys", input_type=Boolean(optional=True), prefix="--der-keys", doc=InputDocumentation(doc="read keys and certificates as DER file")), ToolInput(tag="in_require_peer_cert", input_type=Boolean(optional=True), prefix="--require-peer-cert", doc=InputDocumentation(doc="verify peer certificate, fail if absent (default)")), ToolInput(tag="in_verify_peer_cert", input_type=Boolean(optional=True), prefix="--verify-peer-cert", doc=InputDocumentation(doc="verify peer certificate if present")), ToolInput(tag="in_ignore_peer_cert", input_type=Boolean(optional=True), prefix="--ignore-peer-cert", doc=InputDocumentation(doc="don't verify peer certificate")), ToolInput(tag="in_output_directory", input_type=Directory(optional=True), prefix="--output-directory", doc=InputDocumentation(doc="[d]irectory: string (default: '.')\nwrite received objects to existing directory d")), ToolInput(tag="in_normal", input_type=Boolean(optional=True), prefix="--normal", doc=InputDocumentation(doc="allow implicit format conversions (default)")), ToolInput(tag="in_write_dataset", input_type=Boolean(optional=True), prefix="--write-dataset", doc=InputDocumentation(doc="write data set without file meta information")), ToolInput(tag="in_disable_new_vr", input_type=Boolean(optional=True), prefix="--disable-new-vr", doc=InputDocumentation(doc="disable support for new VRs, convert to OB")), ToolInput(tag="in_group_length_remove", input_type=Boolean(optional=True), prefix="--group-length-remove", doc=InputDocumentation(doc="always write without group length elements")), ToolInput(tag="in_length_undefined", input_type=Boolean(optional=True), prefix="--length-undefined", doc=InputDocumentation(doc="write with undefined lengths")), ToolInput(tag="in_padding_off", input_type=Boolean(optional=True), prefix="--padding-off", doc=InputDocumentation(doc="no padding (default)")), ToolInput(tag="in_sort_conc_studies", input_type=Boolean(optional=True), prefix="--sort-conc-studies", doc=InputDocumentation(doc="[p]refix: string\nsort studies using prefix p and a timestamp")), ToolInput(tag="in_sort_on_study_uid", input_type=Boolean(optional=True), prefix="--sort-on-study-uid", doc=InputDocumentation(doc="[p]refix: string\nsort studies using prefix p and the Study\nInstance UID")), ToolInput(tag="in_sort_on_patient_name", input_type=Boolean(optional=True), prefix="--sort-on-patientname", doc=InputDocumentation(doc="sort studies using the Patient's Name and\na timestamp")), ToolInput(tag="in_default_filenames", input_type=Boolean(optional=True), prefix="--default-filenames", doc=InputDocumentation(doc="generate filename from instance UID (default)")), ToolInput(tag="in_time_names", input_type=Boolean(optional=True), prefix="--timenames", doc=InputDocumentation(doc="generate filename from creation time")), ToolInput(tag="in_filename_extension", input_type=Boolean(optional=True), prefix="--filename-extension", doc=InputDocumentation(doc="[e]xtension: string\nappend e to all filenames")), ToolInput(tag="in_exec_on_reception", input_type=Boolean(optional=True), prefix="--exec-on-reception", doc=InputDocumentation(doc="[c]ommand: string\nexecute command c after having received and\nprocessed one C-STORE-RQ message")), ToolInput(tag="in_exec_on_eo_study", input_type=Boolean(optional=True), prefix="--exec-on-eostudy", doc=InputDocumentation(doc="[c]ommand: string\nexecute command c after having received and\nprocessed all C-STORE-RQ messages that belong\nto one study")), ToolInput(tag="in_rename_on_eo_study", input_type=Boolean(optional=True), prefix="--rename-on-eostudy", doc=InputDocumentation(doc="having received and processed all C-STORE-RQ\nmessages that belong to one study, rename\noutput files according to certain pattern")), ToolInput(tag="in_eo_study_timeout", input_type=Boolean(optional=True), prefix="--eostudy-timeout", doc=InputDocumentation(doc="[t]imeout: integer\nspecifies a timeout of t seconds for\nend-of-study determination")), ToolInput(tag="in_exec_sync", input_type=Boolean(optional=True), prefix="--exec-sync", doc=InputDocumentation(doc="execute command synchronously in foreground")), ToolInput(tag="in_port", input_type=String(), position=0, doc=InputDocumentation(doc="tcp/ip port number to listen on")), ToolInput(tag="in_string", input_type=String(), position=0, doc=InputDocumentation(doc="use specified password"))], outputs=[ToolOutput(tag="out_output_directory", output_type=Directory(optional=True), selector=InputSelector(input_to_select="in_output_directory", type_hint=File()), doc=OutputDocumentation(doc="[d]irectory: string (default: '.')\nwrite received objects to existing directory d"))], container="quay.io/biocontainers/dcmtk:3.6.5--h5fca97b_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Storescp_V0_1_0().translate("wdl")

